ManualHbox Example
===============================================================================

:download:`manual_hbox.enaml <../../../examples/layout/advanced/manual_hbox.enaml>`

.. literalinclude:: ../../../examples/layout/advanced/manual_hbox.enaml
    :language: python

::

 $ enaml-run manual_hbox.enaml

.. image:: images/manual_hbox.png
